function [Tmodel] = SpecDTDSTmodelfn(Xtic1,WhichXtic,Xtic2,fr,F,param)

%SpecDTDSModelfn returns the calculated (complex) transmission coefficient of 
%  a three-layer system at a given frequency, omega. The function has
%  internal constants describing the sample thickness in meters, and
%  the dielectric constants of layer1, layer3 and the air (or substrate,
%  depending on what the sample displaces).  Note that this models a
%  reference case where layer1 and layer3 are in contact with each other
%  (i.e. when sample is removed).
%
%  Input1: x = (refractive index of medium 2, kappa of medium 2)
%  Input2: reference frequency
%  Input3: parameters
%    - .c0
%    - .L2 length of sample
%    - .n1 complex refractive index of medium 1, pre sample
%    - .n3 complex refractive index of medium 3, post sample
%    - .ns compex refractive index of substrate (displaced by sample)
%    - .fp boolean - '1' to include the Fabry-Perot correction factor
%    (i.e.  more than one pulses in the sample waveform overlap)
%    - Version of experimental setup
%
%  Sam Mickan Aug 2001

% Constants
omega=2*pi*F;
c0=param.c0;
L2=param.L2;
n1=param.n1;
n3=param.n3;
%ns=param.ns;

% Xtic (required because this fuction works in a scalar bounded minimisation)
if strcmp(WhichXtic,'Rdex'), Rdex=Xtic1; Kappa=Xtic2; elseif ...
    strcmp(WhichXtic,'Kappa'), Kappa=Xtic1; Rdex=Xtic2; else printf('Error\n')
end, n2=Rdex-j*Kappa;

% Fabry-Perot effects
if 1==1 %strcmp(param.FP,'In')
    FP=1./(1-(n2-n1)./(n2+n1).*(n2-n3)./(n2+n3).*exp(-2.*j.*n2.*omega.*L2./c0)); else
    FP=1;  fprintf('NOT modelling for any FP reflections\n'), end %if param.FP==1
    
% (Complex) transmission coefficient, depending on experimental setup
Tran=1 - 2.*n2.*(n1+n3)./((n1+n2).*(n2+n3)).*exp(-j.*(n2-n3).*omega.*L2./c0).*FP;

% The unwrap step is very important in providing the correct phase value
TranAbs=abs(Tran); TranArg=unwrap(angle(Tran));

% Loop thru diffnt freqs
for cK=1:length(fr)

    % Find discrete frequency values on both sides of fr
    Fr=F(:,1);
    val1=max(find(Fr<=fr(cK))); val2=min(find(Fr>=fr(cK)));

    % Transmission at specific frequency from linear approximation of slope
    %  around point fr
    if val1==val2, TranAbsLoc(cK,:)=TranAbs(val1,:); else
    aAbs=(TranAbs(val2,:)-TranAbs(val1,:))./(Fr(val2)-Fr(val1));
    bAbs=TranAbs(val1,:)-aAbs.*F(val1,:);
    TranAbsLoc(cK,:)=aAbs.*fr(cK)+bAbs;
    aArg=(TranArg(val2,:)-TranArg(val1,:))./(Fr(val2)-Fr(val1));
    bArg=TranArg(val1,:)-aArg.*F(val1,:);
    TranArgLoc(cK,:)=aArg.*fr(cK)+bArg; end %if val1==val2

end %for cK=1:length(fr)

% Prepare the output
Tmodel=struct('Abs',TranAbsLoc',...
    'Arg',TranArgLoc');