% SPM_GENERICMULTIPLOT.M
% For plotting any one or multiple waveforms and their spectra.
%
% Parameters are:
%   DataFile.ID (used to uniquely identify each waveform - *must*
%     be a single ASCII char).
%   .Di: 'Directory' where data files are.
%   .Pa: 'Path(s)' is cells of strings of the file names, without any suffix
%     (eg. '*x.txt').
%   .DC: 'Data Column' where the data, as opposed to the stage step, is stored.
%   .dd: ACTUAL (double the stage step) path length delay step size (in m).
%   .CP: 'Cutoff Points'  is the number of points used from the data waveform,
%     including any desired clipping.
%   .CF: 'Cutoff Freq(s)' to cut the unwrapped and displayed spectra (in Hz).
%   .Le: 'Legend' text(s).
%   .Tr: for any spectral ratios, which waveforms to use (DataFile.IDs -
%     *must* be formatted as a row made up of pairs of IDs);
%    The REFERENCE ID always goes SECOND;
%     Note that any waveforms for ratios must have the same no. of pts and
%     same delay step size.
%   .Dt: for any DTDS plots, which waveforms to use (DataFile.IDs: same
%      format as for 'Tr').
%   .Mo: for Monoscan DTDS plots, which waveforms to use (DataFile.IDs: similar
%      format as for 'Tr' - that is, {y_diff,y_mean,y_diff,y_mean,y_diff,y_mean,etc}).
%   .Fi: the figure number(s) to be exported to an EPSC2 file (COLUMN vector:
%      eg. 'Fi=[1;2]').
%   .Ti: the dir and filename to be used when exporting (array of cells:
%      eg. 'Ti={'Data/2002_03_27/Fig1','Data/2002_03_27/Fig2'}').
%   .FO: 'Figures On', if set to '0' then waveform and spectral plots
%    will not be displayed.
%   .PP: 'Pump Power', if exists is a ROW of IDs - normalize each of the
%     waveforms with an ID listed to a signal proportional to the pump
%     beam power, named '*p.txt'.
%   .FP: 'Fabry-Perot' is the number of FP reflections in <something>, 
%     depending on the specific experiment. Eg. in DTDS simultions,
%     it's the number of reflections in the SUBSTRATE SLIDE (see
%     'Matlab/SPM_SimulateDTDS.m' and 'Notes/Biosensor.tex').
%   .ds: the sample thickness, if required by part of the algorithm,
%     or a super routine (eg. DualSamp) (in m).
%     For DTDS.Sim, .ds becomes a vector of layer thicknesses:
%     [substrate,sensor,target].
%     If one of these values is zero, then the layer is not included in sim.
%   .n1: in DTDS simulations, the complex rdex (n-j*k) of the surrounding
%     medium.
%   .nx: in DTDS simulations, the complex rdex (n-j*k) of the solid
%     substrate for the thin film / sensor (e.g. glass or quartz).
%   .ns: in DTDS simulations, the complex rdex (n-j*k) of the thin film
%     layer, or of the target layer in biosensors (has only 50% coverage).
%   .n2: in DTDS simulations, the complex rdex (n-j*k) of the sensor
%     layer deposited on the substrate. If this is not present, set .ds(2)=0.
%   .Ph: 'Phase Reversal Factor,' is '1' or '-1' to correct the phase of the
%      simulated pulse in DTDS.Sim.
%   .Bi: 'Big,' is '1' if ns > nx and '-1' if ns < nx in DTDS.Sim.

%
% Plots are:
%   Waveforms:
%   Spectra:
%   Spectral Ratios:
%   DTDS Spectral Ratios:
%
% Sam Mickan Oct 2001, Jan 2002.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PRELIM
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~exist('DO_NOT_CLEAR')
    cd ../
	clear
	fprintf('\n\n ***************************************************************')
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Start
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('\n **** Sam: Generic Multi Waveform Plotting Script **** ')
c0=2.99792e8;
if ~exist('LineStyle')
    MyFontSize = 14;
	MyLineWidth = 2;
	LineStyle={'k.',':b','-r.','-c.','-m.','-g.','-y.','-k','-b','-r','-c','-m','-g','-y',':k',':b',':r',':c',':m',':g',':y',':k',':b',':r',':c',':m',':g',':y'};
	%LineStyle={'-k',':k','-ko','-k+','-k*','-kp','k.',':k.','ko','k+','k*','kp','-k.',':k','-ko','-k+','-k*','-kp','k.',':k.','ko','k+','k*','kp'};
	%LineStyle={'-b.','-b.','-b.','-b.','-b.','-b.','-r.','-r.','-r.','-r.','-r.','-r.'};
	%LineColor={[0 0 1],[0 .5 0],[1 0 0],[0 .75 .75],[.75 0 .75],[.75 .75 0],[.25 .25 .25],[.25 0 1],[.5 .5 0],[1 .5 0],[.25 .75 .75],[1 0 .75],[1 .75 0],[.5 .25 .25]};
	LineColor={[0 0 1],[0 0 1],[0 .5 0],[0 .5 0],[1 0 0],[1 0 0],[0 .75 .75],[0 .75 .75],[.75 0 .75],[.75 0 .75],[.75 .75 0],[.75 .75 0],[.25 .25 .25],[.25 .25 .25],[.25 0 1],[.25 0 1],[.5 .5 0],[.5 .5 0],[1 .5 0],[1 .5 0],[.25 .75 .75],[.25 .75 .75],[1 0 .75],[1 0 .75],[1 .75 0],[1 .75 0],[.5 .25 .25],[.5 .25 .25]};
	%LineMarker={'none','none','none','none','none','none','none','none','none','none','none','none','none','none','.','.','.','.','.','.','.','.','.','.','.','.','.','.','o','o','o','o','o','o','o','o','o','o','o','o','o','o','+','+','+','+','+','+','+','+','+','+','+','+','+','+','p','p','p','p','p','p','p','p','p','p','p','p','p','p'};
	LineMarker={'none','.'};
end

	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load up parameters for this extraction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~exist('expfile')
	%expfile=<filename>
    expfile='..\Example_Raw_Data_Files\SamGenericMultiPlot_PrettyPulse.txt';
end

fprintf('\n ----  Expfile:%s',expfile)
[DataFile,Path,Legend,PlotTitle]=SPM_GenericMultiPlotLoadFilefn(expfile);
DataFilePath=Path{1};
DataFileLegendText=Legend{1};
PlotTitle=PlotTitle{1};
titl=expfile; titl=titl(1:(length(titl)-4)); titl(find(titl=='_'))='-';


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run prog.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for cK=(1:length(DataFile.ID))
	% Load waveform
    LoadVar=load('-ascii',[DataFile.Di DataFilePath{cK} 'x.txt']);
    Wave{cK}=LoadVar([1:DataFile.CP(cK)],DataFile.DC(cK));
    Time{cK}=[0:length(Wave{cK})-1]*DataFile.dd(cK)/c0;
	% Normalize to the pump beam power, if recorded
	if ~isempty(DataFile.PP) & ~isempty(find(DataFile.ID(cK)==DataFile.PP))
		fprintf('\n Normalize to pump power (%d): NB: DOES NOT CORRELATE.',cK)
		LoadVar=load('-ascii',[DataFile.Di DataFilePath{cK} 'p.txt']);
		PumpPower{cK}=LoadVar([1:DataFile.CP(cK)],DataFile.DC(cK));
		Wave{cK} = Wave{cK}./PumpPower{cK};
	end
    % Insert manual windowing fun. here (multiply in the time domain)
	% FFT w/ ZeroPad
	fprintf('\n -- Zero-padding time-domain waveform')
	PadMultiple = DataFile.PM; fprintf(' (PadMultiple = %d).',PadMultiple)
	FT{cK}=fft(Wave{cK},PadMultiple*length(Wave{cK}));
	Abs{cK}=abs(FT{cK});
    FreqAbs{cK}=[0:(length(Abs{cK})-1)]'/(DataFile.dd(cK)/...
        c0*(length(Abs{cK})-1));
    NCutAbs{cK}=[max(find(FreqAbs{cK}<=DataFile.CF(cK,1))):...
            min(find(FreqAbs{cK}>=DataFile.CF(cK,2)))];
    Wrapped=angle(FT{cK});
    FreqArg{cK}=FreqAbs{cK}(NCutAbs{cK});
	% Minus inserted to give a +ve, incr. phase, as implied by the
	%  refractive index Eq. (10) in [arjava90] (2002.05.09).
	PreArg = -unwrap(Wrapped(NCutAbs{cK}));
	Slope = mean(diff(PreArg)./diff(FreqArg{cK}));
	Arg{cK} = PreArg + Slope*FreqArg{cK}(1) - PreArg(1);
    % Band pass filter
	BPF{cK} = zeros(length(FT{cK}),1); BPF{cK}(NCutAbs{cK}) = 1;
	% Smoothed waveform
	WaveSmooth{cK} = real(ifft(FT{cK}.*BPF{cK},length(Wave{cK})));
end, clear LoadVar Wrapped cK  PreArg Slope
% Transmission (and Normalisation) for traditional TDS data:
for cK=1:(size(DataFile.Tr,2)/2)
    TranAbs{cK}=Abs{find(DataFile.ID==DataFile.Tr(2*cK-1))}./...
        Abs{find(DataFile.ID==DataFile.Tr(2*cK))};
    TranArg{cK}=Arg{find(DataFile.ID==DataFile.Tr(2*cK-1))}-...
        Arg{find(DataFile.ID==DataFile.Tr(2*cK))};
    TransFileLegndText{cK} = ...
        [DataFileLegendText{find(DataFile.ID==DataFile.Tr(2*cK-1))} ...
            ' / ' DataFileLegendText{find(DataFile.ID==DataFile.Tr(2*cK))}];
	% Normalise 1st file to the AMPD of the 2nd
	WaveNormSmooth{cK} = ...
		real(ifft(FT{find(DataFile.ID==DataFile.Tr(2*cK-1))}./...
		Abs{find(DataFile.ID==DataFile.Tr(2*cK))}.*...
		BPF{find(DataFile.ID==DataFile.Tr(2*cK-1))},...
		length(Wave{find(DataFile.ID==DataFile.Tr(2*cK-1))})));
end, clear cK
% Transmission for DTDS data:
for cK=1:(size(DataFile.Dt,2)/2)
	Ref = Wave{find(DataFile.ID==DataFile.Dt(2*cK))};
	Sam =  Ref - Wave{find(DataFile.ID==DataFile.Dt(2*cK-1))};
	SamFT = fft(Sam);
    SamAbs = abs(SamFT);
    SamWrapped = angle(SamFT);
    SamArg = unwrap(SamWrapped(NCutAbs{find(DataFile.ID==DataFile.Dt(2*cK))}));
    DTDSAbs{cK}=SamAbs./...
        Abs{find(DataFile.ID==DataFile.Dt(2*cK))};
    DTDSArg{cK}=...
        - Arg{find(DataFile.ID==DataFile.Dt(2*cK))} + ...
		SamArg;
    DTDSFileLegndText{cK} = ...
        ['1 - ' DataFileLegendText{find(DataFile.ID==DataFile.Dt(2*cK-1))} ...
            ' / ' DataFileLegendText{find(DataFile.ID==DataFile.Dt(2*cK))}];
end, clear cK Ref Sam SamFT SamAbs SamWrapped SamArg
% Transmission for Monoscan DTDS data:
for cK=1:(size(DataFile.Mo,2)/2)
	Mean = Wave{find(DataFile.ID==DataFile.Mo(2*cK))};
	Diff =  Wave{find(DataFile.ID==DataFile.Mo(2*cK-1))};
	Ref{cK} = Mean + Diff;
	Sam{cK} = Mean - Diff;
	FT_r{cK}=fft(Ref{cK},PadMultiple*length(Ref{cK}));
	FT_s{cK}=fft(Sam{cK},PadMultiple*length(Sam{cK}));
	Abs_r{cK}=abs(FT_r{cK});
    Abs_s{cK}=abs(FT_s{cK});
    Wrapped_r = angle(FT_r{cK});
    Wrapped_s = angle(FT_s{cK});
	PreArg_r = -unwrap(Wrapped_r(NCutAbs{2*cK}));
	PreArg_s = -unwrap(Wrapped_s(NCutAbs{2*cK}));
	Slope_r = mean(diff(PreArg_r)./diff(FreqArg{2*cK}));
	Slope_s = mean(diff(PreArg_s)./diff(FreqArg{2*cK}));
	Arg_r{cK} = PreArg_r + Slope_r*FreqArg{2*cK}(1) - PreArg_r(1);	
	Arg_s{cK} = PreArg_s + Slope_s*FreqArg{2*cK}(1) - PreArg_s(1);	
    DTDSTranAbs{cK} = Abs_s{cK}./Abs_r{cK};
    DTDSTranArg{cK} = Arg_s{cK} - Arg_r{cK};
    DTDSTransFileLegndText{cK} = ...
        [DataFileLegendText{find(DataFile.ID==DataFile.Mo(2*cK-1))} ...
            ' / ' DataFileLegendText{find(DataFile.ID==DataFile.Mo(2*cK))}];
end, clear cK Mean Diff Wrapped_r Wrapped_s PreArg_r PreArg_s Slope_r Slope_s


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if eq(DataFile.FO,'0'),  end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot waveforms 'H1'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ne(DataFile.FO,'0')
	H1=figure(1); clf, set(H1,'PaperPosition',[0.1 0.2 6 4],...
		'Name','Waveforms'), A1=axes; set(A1,'NextPlot','add')
	for cK=1:length(DataFile.ID)
		P1{cK} = plot(Time{cK}.*1e12,Wave{cK});
		set(P1{cK},'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1})
	end, clear cK
	set(gca,'FontSize',MyFontSize)
	L1=legend(DataFileLegendText);
	title(titl)
	ylabel('THz Electric Field (a.u.)')
	xlabel('Time (ps)')
	grid on
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot spectra 'H2'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ne(DataFile.FO,'0')
	% Switch
	SubPlotOn=1;
	% Plots
	H2=figure(2); clf, set(H2,'PaperPosition',[0.1 0.2 6 4],...
		'Name','Spectra','NextPlot','add')
	if SubPlotOn
		A22=subplot(212); set(A22,'NextPlot','add')
		A21=subplot(211); set(A21,'NextPlot','add')
	else
		A21=axes; set(A21,'NextPlot','add')
	end
	for cK=1:length(DataFile.ID)
		if  SubPlotOn
			axes(A22)
			%P2=plot(FreqArg{cK}(NCutArg{cK})*1e-12,Arg{cK}(NCutArg{cK}));
			P2=plot(FreqArg{cK}*1e-12,Arg{cK});
			set(P2,'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1})
		end
		axes(A21)
		P1=plot(FreqAbs{cK}(NCutAbs{cK})*1e-12,Abs{cK}(NCutAbs{cK}));
		%P1=semilogy(FreqAbs{cK}(NCutAbs{cK})*1e-12,Abs{cK}(NCutAbs{cK}));
		set(P1,'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1})
	end, clear cK P1 P2
	if SubPlotOn
		set(A22,'FontSize',MyFontSize)
		axes(A22)
		ylabel('Phase (rad)')
		grid on
	end
	set(A21,'FontSize',MyFontSize)
	axes(A21)
	L2=legend(DataFileLegendText);
	title(titl)
	ylabel('Magnitude (a.u.)')
	grid on
	xlabel('Frequency (THz)')
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot smoothed plots 'H5'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ne(DataFile.FO,'0')
	H5=figure(5); clf, set(H5,'PaperPosition',[0.1 0.2 6 4],...
		'Name','SmoothWaveforms')
	A5=axes; set(A5,'NextPlot','add')
	for cK=1:length(DataFile.ID)
		H5A{cK} = plot(Time{cK}.*1e12,WaveSmooth{cK});
		set(H5A{cK},'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1},...
			'LIneWidth',MyLineWidth)
	end, clear cK
	set(gca,'FontSize',MyFontSize)
	L5=legend(DataFileLegendText);
	title(titl)
	ylabel('THz Electric Field (a.u.)')
	xlabel('Time (ps)')
	grid on
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot spectral ratios 'H3'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~isempty(DataFile.Tr) & ne(DataFile.FO,'0')
	% Switch
	SubPlotOn = 0;
	% Plots
    H3=figure(3); clf, set(H3,'PaperPosition',[0.1 0.2 6 4],'Name','Trans')
	if SubPlotOn
		A31=subplot(211); set(A31,'NextPlot','add')
		A32=subplot(212); set(A32,'NextPlot','add')
	else
		A31=axes; set(A31,'NextPlot','add')
	end
    for cK=1:(size(DataFile.Tr,2)/2)
		axes(A31)
		P1 = plot(FreqAbs{cK}(NCutAbs{cK})*1e-12,TranAbs{cK}(NCutAbs{cK})); hold on
		%P1 = semilogy(FreqAbs{cK}(NCutAbs{cK})*1e-12,TranAbs{cK}(NCutAbs{cK})), hold on
		set(P1,'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1});
		if SubPlotOn
			axes(A32)
			%P2 = plot(FreqArg{cK}(NCutArg{cK})*1e-12,TranArg{cK}(NCutArg{cK})), hold on
			P2 = plot(FreqArg{cK}*1e-12,TranArg{cK}); hold on    
			set(P2,'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1})
		end
	end, clear cK
    axes(A31)
    set(gca,'FontSize',MyFontSize)
    L3=legend(TransFileLegndText);
    title(titl)
    ylabel('Magnitude (a.u.)')
    grid on
	if SubPlotOn
		axes(A32)
		set(gca,'FontSize',MyFontSize)
		ylabel('Phase (rad)')
		xlabel('Frequency (THz)')
		grid on
	end
end %if


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot normalised smoothed plots 'H6'
%  (these look terrible)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0 %~isempty(DataFile.Tr) & ne(DataFile.FO,'0')
	H6=figure(6); clf, set(H6,'PaperPosition',[0.1 0.2 6 4],...
		'Name','NormalisedSmoothWaveforms')
	A6=axes; set(A6,'NextPlot','add')
	for cK = 1:(size(DataFile.Tr,2)/2)
		H6A{cK} = plot(Time{cK}.*1e12,WaveNormSmooth{cK});
		set(H6A{cK},'Color',LineColor{mod(cK-1,14)+1},'Marker',LineMarker{mod(cK-1,2)+1},...
			'LineWidth',MyLineWidth)
	end, clear cK
	set(gca,'FontSize',MyFontSize)
	L6=legend(DataFileLegendText);
	title(titl)
	ylabel('THz Electric Field (a.u.)')
	xlabel('Time (ps)')
	grid on
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot DTDS ratios 'H4'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~isempty(DataFile.Dt) & ne(DataFile.FO,'0')
    H4=figure(4); clf, set(H4,'PaperPosition',[0.1 0.2 6 4],'Name','DTDS')
    for cK=1:(size(DataFile.Dt,2)/2)
        subplot(211)
		% PLOT DTDS TRANSMISSION: (1-S/R) ******
        plot(FreqAbs{cK}(NCutAbs{cK})*1e-12,DTDSAbs{cK}(NCutAbs{cK}),LineStyle{cK}), hold on
        subplot(212)
        %plot(FreqArg{cK}(NCutArg{cK})*1e-12,TranArg{cK}(NCutArg{cK}),LineStyle{cK}), hold on
        plot(FreqArg{cK}*1e-12,DTDSArg{cK},LineStyle{cK}), hold on    
    end, clear cK
    subplot(211)
    set(gca,'FontSize',14)
    L4=legend(DTDSFileLegndText);
    set(L4,'FontSize',14)
    title(titl)
    ylabel('Magnitude (a.u.)','FontSize',14)
    grid on
    subplot(212)
    ylabel('Phase (rad)','FontSize',14)
    xlabel('Frequency (THz)','FontSize',14)
    set(gca,'FontSize',14)
    grid on
end %if


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Export selected plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for cK=1:length(DataFile.Fi)
    figure(DataFile.Fi(cK))
    if DataFile.Fi(cK)==1
		title(''), grid off
		ylabel('mag'), xlabel('tim')
	elseif (DataFile.Fi(cK)==2) | (DataFile.Fi(cK)==3)
        subplot(211)
        title(''), grid off
		ylabel('mag')
        subplot(212)
		ylabel('pha'), xlabel('fre'), grid off
	end
    %print('-depsc2',PlotTitle{cK})
    %print('-dmeta',PlotTitle{cK})
	print('-dtiff',PlotTitle{cK})
    if DataFile.Fi(cK)==1
		title(titl), grid off
		ylabel('THz Electric Field (a.u.)'), xlabel('Time (ps)')
	elseif (DataFile.Fi(cK)==2) | (DataFile.Fi(cK)==3)
        subplot(211)
        title(titl), grid on
		ylabel('Magnitude (a.u.)')
        subplot(212)
		ylabel('Phase (rad)'), xlabel('Frequency (THz)'), grid on
	end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0 % Difference Waveform
    Sensitivity=1 %input('What is sensitivity (as fraction of 1.0)?')
    H5=figure(5); clf, set(H5,'PaperPosition',[0.1 0.2 6 4],'Name','Difference')
    subplot(211)
    plot(Time{3},Wave{3}.*Sensitivity,'-',Time{3},0.5*(Wave{1}-Wave{2}),':.r')
    %plot(Time{3},Wave{3}.*Sensitivity,'-',Time{3},(Wave{1}-Wave{2}),':.r',...
    %    Time{4},2*Wave{4},Time{5},Wave{5})
    legend('DTDS','0.5*(Glass-Tape)') %,'Repeat-f1','Repeat-f2')
    title(titl)
    subplot(212)
    Sd=fft(Wave{3}.*Sensitivity); Sdiff=fft(0.5*(Wave{1}-Wave{2}));
    plot(FreqAbs{1}(NCutAbs{1}),abs(Sd(NCutAbs{1})),'-',...
		FreqAbs{1}(NCutAbs{1}),abs(Sdiff(NCutAbs{1})),':.r')
    %subplot(313)
    %Dif=fft(Wave{3}.*Sensitivity,NPhase); RefMinSam=fft((Wave{1}-Wave{2}),NPhase);
    %plot(FreqArg{1}(NCutArg{1}),unwrap(angle(Dif(NCutArg{1}))),'-',...
    %    FreqArg{1}(NCutArg{1}),unwrap(angle(RefMinSam(NCutArg{1}))),':.r')
    %print('-deps2','MyPictures/Matlab_2002_01_25_DTDS.eps')
end
if 0 % Slow time scans of repeatability
    %***PROBLEMS STILL***
    dt=1 %sec
    H2=figure(2); clf, set(H2,'PaperPosition',[0.1 0.2 6 4],'Name','Spectra')
    for cK=1:length(DataFile.ID)
        subplot(211)
        N=length(Abs{cK});
        NewFreqAbs=[0:(N-1)]/(N-1)/dt;
        plot(NewFreqAbs(3:round(N/4)),Abs{cK}(3:round(N/4)),LineStyle{cK}), hold on
        subplot(212)
        NewFreqArg=[0:(length(Arg{cK})-1)]/(length(Arg{cK})-1)/dt;
        plot(NewFreqArg,Arg{cK},LineStyle{cK}), hold on
    end, clear cK
    subplot(211)
    L2=legend(DataFileLegendText);
    set(L2,'FontSize',14)
    title(mfilename)
    ylabel('MAGNITUDE','FontSize',14)
    set(gca,'FontSize',14)
    subplot(212)
    ylabel('PHASE00RAD0','FontSize',14)
    xlabel('FREQUENCY00HZ0','FontSize',14)
    set(gca,'FontSize',14)
end
if 0
    grid on
    ylim=[0,1]; xlim=[0 3.2];
    errorbar(Spectra.F(Ncut)*1e-12,TranAbs(Ncut),TAbsEbar)
end
if 0 % ERROR BARS
	Error = 0.001; % for today, +/-1mV
	H10=figure(10); clf, set(H10,'PaperPosition',[0.1 0.2 6 4],...
		'Name','Waveforms - Error')
	for cK=1:length(DataFile.ID)
		errorbar(Time{cK}*1e12,Wave{cK},...
			ones(size(Wave{cK})).*Error,LineStyle{cK}), hold on
	end, clear cK
	set(gca,'FontSize',14)
	L10=legend(DataFileLegendText);
	set(L10,'FontSize',14)
	title(titl)
	ylabel('THZ0ELECTRIC0FIELD00AU0','FontSize',14)
	xlabel('DELAY0TIME00PS0','FontSize',14)
	grid on
end
if 0 % Spectral magnitude on seperate plot, plots with no text
	% WAVEFORM
	H1=figure(1); clf, set(H1,'PaperPosition',[0.1 0.2 6 4],...
		'Name','Waveforms')
	for cK=1:length(DataFile.ID)
		plot(Time{cK}*1e12,Wave{cK},LineStyle{cK},'LineWidth',2), hold on
	end, clear cK
	set(gca,'FontSize',14,'LineWidth',2)
	ylim([-0.1 0.2]), xlim([0 30])
	print('-depsc2',PlotTitle{1})
	% SPECTRUM
	H6=figure(2); clf, set(H6,'PaperPosition',[0.1 0.2 6 4],'Name','Spectra')
	for cK=1:length(DataFile.ID)
    %plot(FreqAbs{cK}(NCutAbs{cK})*1e-12,Abs{cK}(NCutAbs{cK}),LineStyle{cK}), hold on
    semilogy(FreqAbs{cK}(NCutAbs{cK})*1e-12,Abs{cK}(NCutAbs{cK}),LineStyle{cK},'LineWidth',2), hold on
    end, clear cK
	set(gca,'FontSize',14,'LineWidth',2)
	print('-depsc2',PlotTitle{2})
end